@@ -17,7 +17,7 @@ enum {
   APP_LP_FILE_ENCODING = END_OF_APP_BPS, APP_LP_EDIT_FONT_SIZE, APP_LP_EDIT_HEIGHT,
   APP_LP_EDIT_WIDTH, 
   APP_LP_SCREEN_WIDTH, APP_LP_SCREEN_HEIGHT, APP_LP_SCREEN_WIDTH_H, APP_LP_SCREEN_HEIGHT_H, 
-  APP_LP_STYLE, APP_LP_DOCK_STYLE, APP_LP_DOCK_POSITION, 
+  APP_LP_STYLE, APP_LP_DOCK_STYLE, APP_LP_DOCK_POSITION, APP_LP_X, APP_LP_Y,
 #ifdef WITH_MAEMO
   APP_LP_MAEMO_SIZE,
 #endif
