@@ -47,6 +47,8 @@ CAlphabet::CAlphabet(const CAlphIO::AlphInfo &AlphInfo)
   m_StartConversionSymbol = -1;
   m_EndConversionSymbol = -1;
 
+  m_iResetSymbol = -1;
+
   m_strDefaultContext = AlphInfo.m_strDefaultContext;
 
   // Set miscellaneous options
@@ -61,6 +63,8 @@ CAlphabet::CAlphabet(const CAlphIO::AlphInfo &AlphInfo)
     AddChar(it->Text, it->Display, it->Colour, it->Foreground);
 
 
+  // TODO: Special characters are a mess - really need to think these through
+
   // Set Space character if requested
 
   // This line makes it a bit easier for our WindowsCE compiler
@@ -88,6 +92,11 @@ CAlphabet::CAlphabet(const CAlphIO::AlphInfo &AlphInfo)
   if(AlphInfo.ControlCharacter.Display != std::string("") && GetControlSymbol() == -1)
     AddControlSymbol(AlphInfo.ControlCharacter.Text, AlphInfo.ControlCharacter.Display, AlphInfo.ControlCharacter.Colour, AlphInfo.ControlCharacter.Foreground);
 
+  if(AlphInfo.ResetCharacter.Text != empty)
+    AddResetSymbol(AlphInfo.ResetCharacter.Text, AlphInfo.ResetCharacter.Display, 
+		   AlphInfo.ResetCharacter.Colour, AlphInfo.ResetCharacter.Foreground);
+
+
   // New group stuff
 
   m_pBaseGroup = AlphInfo.m_pBaseGroup;
@@ -166,6 +175,43 @@ void CAlphabet::GetSymbols(std::vector<symbol > *Symbols, std::string *Input, bo
     Symbols->push_back(CurSymbol);
 }
 
+void CAlphabet::GetSymbolsFull(std::vector<symbol > *Symbols, std::string *Input) const {
+ 
+  std::string::iterator it = Input->begin();
+
+  while(it != Input->end()) {
+    unsigned char c = static_cast<unsigned char>(*it);
+
+    int iNBytes;
+
+    if(c <= 0x7F)
+      iNBytes = 1;
+    else if((c >= 0xC2) && (c <= 0xDF))
+      iNBytes = 2;
+    else if((c >= 0xE0) && (c <= 0xEF))
+      iNBytes = 3;
+    else if((c >= 0xF0) && (c <= 0xF4))
+      iNBytes = 4;
+    else {
+      // TODO: Error condition - handle this.
+      iNBytes = 1;
+    }
+
+    std::string strCurrentSymbol(1, *it);
+
+    for(int i = 0; i < iNBytes - 1; ++i) {
+      ++it;
+      strCurrentSymbol += *it;
+    }
+
+    // TODO: Error condition on reaching end of string prematurely.
+
+    Symbols->push_back(TextMap.Get(strCurrentSymbol, false));
+
+    ++it;
+  }
+}
+
 // add single char to the character set
 void CAlphabet::AddChar(const std::string NewCharacter, const std::string Display, int Colour, const std::string Foreground) {
   m_Characters.push_back(NewCharacter);
@@ -212,6 +258,12 @@ void CAlphabet::AddEndConversionSymbol(const std::string NewCharacter, const std
   m_EndConversionSymbol = GetNumberSymbols() - 1;
 }
 
+void CAlphabet::AddResetSymbol(const std::string NewCharacter, const std::string Display, int Colour, const std::string Foreground) {
+  AddChar(NewCharacter, Display, Colour, Foreground);
+  m_iResetSymbol = GetNumberSymbols() - 1;
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 // diagnostic dump of character set
 
@@ -280,3 +332,26 @@ int CAlphabet::GetTextColour(symbol Symbol) {
 // }
 
 /////////////////////////////////////////////////////////////////////////////
+
+int CAlphabet::GetColour(symbol i, int iPhase) const {
+  int iColour = m_Colours[i];
+  
+  // This is for backwards compatibility with old alphabet files -
+  // ideally make this log a warning (unrelated TODO: automate
+  // validation of alphabet files, plus maintenance of repository
+  // etc.)
+  if(iColour == -1) {
+    if(i == m_SpaceSymbol) {
+      iColour = 9;
+    }
+    else {
+      iColour = (i % 3) + 10;
+    }
+  }
+  
+  // Loop on low colours for nodes (TODO: go back to colour namespaces?)
+  if(iPhase == 1 && iColour < 130)
+    iColour += 130;
+  
+  return iColour;
+} 
