@@ -41,8 +41,13 @@ namespace Dasher {
     int GetNumberSymbols() const {
       return m_Characters.size();
     }                           // return size of alphabet
-    // Return number of text symbols 
+
+    /// Return number of text symbols 
+    /// Text symbols are everything which doesn't generate a new root, 
+    /// i.e. control mode and conversion mode
     int GetNumberTextSymbols() const {
+
+      // TODO: This really does need to be fixed, as this will sometimes be 2
       return m_Characters.size() - 1;
     } 
 
@@ -81,19 +86,7 @@ namespace Dasher {
     } 
     // return string for i'th symbol
 
-    int GetColour(symbol i) const {
-      return m_Colours[i];
-    } 
-    // return the colour for i'th symbol
-
-/*     int GetGroupColour(int i) const { */
-/*       return m_GroupColour[i]; */
-/*     }  */
-    // return the colour for i'th group 
-
-/*     std::string GetGroupLabel(int i)const { */
-/*       return m_GroupLabel[i]; */
-/*     } */
+    int GetColour(symbol i, int iPhase) const;
 
     int GetTextColour(symbol i);      // return the foreground colour for i'th symbol
     const std::string & GetForeground(symbol i) const {
@@ -119,6 +112,14 @@ namespace Dasher {
     // defined as its own symbol. }}}
     void GetSymbols(std::vector<symbol> *Symbols, std::string * Input, bool IsMore) const;
 
+
+    /// Look up symbols corresponding to string. Cannot cope with
+    /// parial input, but knows about UTF-8, so can include 'unknown
+    /// symbol' as 0 in the output. Slower than GetSymbols, so don't
+    /// use for import, but is useful for looking up contexts.
+    void GetSymbolsFull(std::vector<symbol > *Symbols, std::string *Input) const;
+
+
     void Trace() const;         // diagnostic
 
     // Add the characters that can appear in Nodes
