@@ -27,6 +27,7 @@
 #include "EventHandler.h"
 #include "NodeCreationManager.h"
 
+
 #include <vector>
 #include <sstream>
 #include <iostream>
@@ -43,17 +44,15 @@ static char THIS_FILE[] = __FILE__;
 #endif
 #endif
 
-CAlphabetManager::CAlphabetManager(CDasherInterfaceBase *pInterface, CNodeCreationManager *pNCManager, CLanguageModel *pLanguageModel, CLanguageModel::Context iLearnContext, bool bGameMode, const std::string &strGameModeText ) 
+CAlphabetManager::CAlphabetManager(CDasherInterfaceBase *pInterface, CNodeCreationManager *pNCManager, CLanguageModel *pLanguageModel, CLanguageModel::Context iLearnContext) 
   : CNodeManager(0), m_pLanguageModel(pLanguageModel), m_pNCManager(pNCManager) {
-
   m_pInterface = pInterface;
 
   m_iLearnContext = iLearnContext;
-  m_bGameMode = bGameMode;
-  m_strGameString = strGameModeText;
 }
 
 CDasherNode *CAlphabetManager::GetRoot(CDasherNode *pParent, int iLower, int iUpper, void *pUserData) {
+
   CDasherNode *pNewNode;
 
   // TODO: iOffset has gotten a bit hacky here
@@ -82,7 +81,7 @@ CDasherNode *CAlphabetManager::GetRoot(CDasherNode *pParent, int iLower, int iUp
     BuildContext(strContext, false, iContext, iSymbol);
 
     iOffset = static_cast<SRootData *>(pUserData)->iOffset - 1;
-    iColour = m_pNCManager->GetColour(iSymbol);
+    iColour = m_pNCManager->GetColour(iSymbol, 0);
   }
   else {
     // Create a root node
@@ -127,12 +126,12 @@ CDasherNode *CAlphabetManager::GetRoot(CDasherNode *pParent, int iLower, int iUp
   pNewNode->SetFlag(NF_SEEN, true);
 
 
-
-  if(m_bGameMode) {
-    pNodeUserData->iGameOffset = -1;
-    pNewNode->SetFlag(NF_GAME, true);
-  }
-
+  
+  //    if(m_bGameMode) {
+  //    pNodeUserData->iGameOffset = -1;
+       pNewNode->SetFlag(NF_GAME, true);
+    //  }
+  
   return pNewNode;
 }
 
@@ -175,9 +174,11 @@ CDasherNode *CAlphabetManager::CreateGroupNode(CDasherNode *pParent, SGroupInfo
   SAlphabetData *pNodeUserData = new SAlphabetData;
   pNewNode->m_pUserData = pNodeUserData;
 
-  pNodeUserData->iOffset = pParentData->iOffset;
+  // When creating a group node...
+  pNodeUserData->iOffset = pParentData->iOffset; // ...the offset is the same as the parent...
   pNodeUserData->iPhase = pParentData->iPhase;
-  pNodeUserData->iSymbol = 0; // TODO: Sort out symbol for groups
+  // TODO: Sort out symbol for groups
+  pNodeUserData->iSymbol = 0; //...but the Symbol is just a 0.
   pNodeUserData->pLanguageModel = pParentData->pLanguageModel;
   pNodeUserData->iContext = pParentData->pLanguageModel->CloneContext(pParentData->iContext);
 
@@ -220,40 +221,25 @@ CDasherNode *CAlphabetManager::CreateSymbolNode(CDasherNode *pParent, symbol iSy
 
   }
   // TODO: Need to fix fact that this is created even when control mode is switched off
-  else if(iSymbol == m_pNCManager->GetControlSymbol()) {                                                                               
-    pNewNode = m_pNCManager->GetRoot(1, pParent, iLbnd, iHbnd, &(pParentData->iOffset));                                           
+  else if(iSymbol == m_pNCManager->GetControlSymbol()) {
+    pNewNode = m_pNCManager->GetRoot(1, pParent, iLbnd, iHbnd, &(pParentData->iOffset)); 
 
     // For now, just hack it so we get a normal root node here
     if(!pNewNode) {
       pNewNode = m_pNCManager->GetRoot(0, pParent, iLbnd, iHbnd, NULL);
     }
-  }                                                                                                                                   
-  else if(iSymbol == m_pNCManager->GetStartConversionSymbol()) {                                                                  
+  }
+  else if(iSymbol == m_pNCManager->GetStartConversionSymbol()) {
   //  else if(iSymbol == m_pNCManager->GetSpaceSymbol()) {
 
-    // TODO: Need to consider the case where there is no compile-time support for this                                                
-    pNewNode = m_pNCManager->GetRoot(2, pParent, iLbnd, iHbnd, &(pParentData->iOffset));                                           
+    // TODO: Need to consider the case where there is no compile-time support for this
+    pNewNode = m_pNCManager->GetRoot(2, pParent, iLbnd, iHbnd, &(pParentData->iOffset));
   }         
   else {
     int iPhase = (pParentData->iPhase + 1) % 2;
-    int iColour = m_pNCManager->GetColour(iSymbol);
+    int iColour = m_pNCManager->GetColour(iSymbol, iPhase);
     
-    // This is for backwards compatibility with old alphabet files -
-    // ideally make this log a warning (unrelated TODO: automate
-    // validation of alphabet files, plus maintenance of repository
-    // etc.)
-    if(iColour == -1) {
-      if(iSymbol == m_pNCManager->GetSpaceSymbol()) {
-	iColour = 9;
-      }
-      else {
-	iColour = (iSymbol % 3) + 10;
-      }
-    }
-    
-    // Loop on low colours for nodes (TODO: go back to colour namespaces?)
-    if(iPhase == 1 && iColour < 130)
-      iColour += 130;
+   
     
     // TODO: Exceptions / error handling in general
 
@@ -306,16 +292,30 @@ void CAlphabetManager::RecursiveIterateGroup(CDasherNode *pParent, SGroupInfo *p
   }
 
   // Create child nodes and cache them for later
+  // The SGroupInfo structure has something like linked list behaviour
+  // Each SGroupInfo contains a pNext, a pointer to a sibling group info
   SGroupInfo *pCurrentNode(pInfo);
   while(pCurrentNode) {
-    CDasherNode *pNewChild = CreateGroupNode(pParent, pCurrentNode, pCProb, pCurrentNode->iStart, pCurrentNode->iEnd, iMin, iMax);
-    RecursiveIterateGroup(pNewChild, pCurrentNode->pChild, pSymbols, pCProb, pCurrentNode->iStart, pCurrentNode->iEnd, iExistingSymbol, pExistingChild);
+    CDasherNode *pNewChild = CreateGroupNode(pParent,
+					     pCurrentNode,
+					     pCProb,
+					     pCurrentNode->iStart,
+					     pCurrentNode->iEnd,
+					     iMin, iMax);
+
+    RecursiveIterateGroup(pNewChild,
+			  pCurrentNode->pChild,
+			  pSymbols,
+			  pCProb,
+			  pCurrentNode->iStart,
+			  pCurrentNode->iEnd,
+			  iExistingSymbol, pExistingChild);
 
     for(int i(pCurrentNode->iStart); i < pCurrentNode->iEnd; ++i) {
       pChildNodes[i - iMin] = pNewChild;
     }
 
-    pCurrentNode = pCurrentNode->pNext;
+    pCurrentNode = pCurrentNode->pNext; // Move along the group
   }
 
   CDasherNode *pLastChild = NULL;
@@ -357,7 +357,8 @@ void CAlphabetManager::PopulateChildrenWithSymbol( CDasherNode *pNode, int iExis
     cum[i] += cum[i - 1];
   }
 
-  RecursiveIterateGroup(pNode, m_pNCManager->GetAlphabet()->m_pBaseGroup, &newchars, &cum, 1, iChildCount, iExistingSymbol, pExistingChild);
+  RecursiveIterateGroup(pNode, m_pNCManager->GetAlphabet()->m_pBaseGroup, &newchars, 
+    &cum, 1, iChildCount, iExistingSymbol, pExistingChild);
 }
 
 void CAlphabetManager::ClearNode( CDasherNode *pNode ) {
@@ -390,8 +391,6 @@ void CAlphabetManager::Output( CDasherNode *pNode, Dasher::VECTOR_SYMBOL_PROB* p
 void CAlphabetManager::Undo( CDasherNode *pNode ) {
   symbol t = static_cast<SAlphabetData *>(pNode->m_pUserData)->iSymbol;
 
-  //std::cout << pNode << " " << pNode->Parent() << ": Undo at offset " << static_cast<SAlphabetData *>(pNode->m_pUserData)->iOffset << " *" << m_pNCManager->GetAlphabet()->GetText(t) << "* " << std::endl;
-
   if(t) { // Ignore symbol 0 (root node)
     Dasher::CEditEvent oEvent(2, m_pNCManager->GetAlphabet()->GetText(t), static_cast<SAlphabetData *>(pNode->m_pUserData)->iOffset);
     m_pNCManager->InsertEvent(&oEvent);
@@ -399,10 +398,7 @@ void CAlphabetManager::Undo( CDasherNode *pNode ) {
 }
 
 // TODO: Sort out node deletion etc.
-CDasherNode *CAlphabetManager::RebuildParent(CDasherNode *pNode, int iGeneration) {
-
-  // TODO: iGeneration obsolete?
-
+CDasherNode *CAlphabetManager::RebuildParent(CDasherNode *pNode) {
   int iOffset(static_cast<SAlphabetData *>(pNode->m_pUserData)->iOffset);
   int iNewOffset = iOffset - 1;
 
@@ -415,9 +411,10 @@ CDasherNode *CAlphabetManager::RebuildParent(CDasherNode *pNode, int iGeneration
 
   std::string strContext;
   CLanguageModel::Context iContext;
-   
-  if(iOffset == -1) {
-    // pNode is already a root
+
+  if((iOffset == -1) || (static_cast<SAlphabetData *>(pNode->m_pUserData)->iSymbol == 0)) {
+    // pNode is already a root, or for some other reason has the null
+    // symbol (eg because it was generated from a different alphabet)
     return NULL;
   }
   else if(iOffset == 0) {
@@ -443,15 +440,12 @@ CDasherNode *CAlphabetManager::RebuildParent(CDasherNode *pNode, int iGeneration
       iStart = 0;
 
     strContext = m_pInterface->GetContext(iStart, iOffset - iStart);
+
     BuildContext(strContext, false, iContext, iNewSymbol);
 
     iNewPhase = ((iOldPhase + 2 - 1) % 2);
 
-    int iColour(m_pNCManager->GetColour(iNewSymbol));
-
-    // Loop colours if necessary for the colour scheme
-    if(iNewPhase == 1)
-      iColour += 130;
+    int iColour(m_pNCManager->GetColour(iNewSymbol, iNewPhase));
             
     CDasherNode::SDisplayInfo *pDisplayInfo = new CDasherNode::SDisplayInfo;
     pDisplayInfo->iColour = iColour;
@@ -479,13 +473,17 @@ CDasherNode *CAlphabetManager::RebuildParent(CDasherNode *pNode, int iGeneration
 
   PopulateChildrenWithSymbol(pNewNode, static_cast<SAlphabetData *>(pNode->m_pUserData)->iSymbol, pNode);
   
+  //  std::cout << "**" << std::endl;
+
   return pNewNode;
 }
 
+// TODO: Shouldn't there be an option whether or not to learn as we write?
+// For want of a better solution, game mode exemption explicit in this function
 void CAlphabetManager::SetFlag(CDasherNode *pNode, int iFlag, bool bValue) {
   switch(iFlag) {
   case NF_COMMITTED:
-    if(bValue)
+    if(bValue && !pNode->GetFlag(NF_GAME))
       // TODO: Reimplement (need a learning context, check whether symbol actually corresponds to character)
       static_cast<SAlphabetData *>(pNode->m_pUserData)->pLanguageModel->LearnSymbol(m_iLearnContext, static_cast<SAlphabetData *>(pNode->m_pUserData)->iSymbol);
     break;
@@ -498,13 +496,14 @@ void CAlphabetManager::BuildContext(std::string strContext, bool bRoot, CLanguag
   // redundant code
 
   std::vector<symbol> vContextSymbols;
-  m_pNCManager->GetAlphabet()->GetSymbols(&vContextSymbols, &strContext, false);
+  m_pNCManager->GetAlphabet()->GetSymbolsFull(&vContextSymbols, &strContext);
  
   oContext = m_pLanguageModel->CreateEmptyContext();
   
   for(std::vector<symbol>::iterator it(vContextSymbols.begin()); it != vContextSymbols.end(); ++it)
-    m_pLanguageModel->EnterSymbol(oContext, *it);
-
+    if(*it != 0)
+      m_pLanguageModel->EnterSymbol(oContext, *it);
+  
   if((vContextSymbols.size() == 0) || bRoot)
     iSymbol = 0;
   else
