@@ -1,12 +1,32 @@
+// ControlManager.cpp
+//
+// Copyright (c) 2007 The Dasher Team
+//
+// This file is part of Dasher.
+//
+// Dasher is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// Dasher is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Dasher; if not, write to the Free Software 
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include "../Common/Common.h"
 
 #include "ControlManager.h"
+
 using namespace Dasher;
 using namespace std;
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -21,6 +41,9 @@ CControlManager::CControlManager( CNodeCreationManager *pNCManager )
   string SystemString = m_pNCManager->GetStringParameter(SP_SYSTEM_LOC);
   string UserLocation = m_pNCManager->GetStringParameter(SP_USER_LOC);
   m_iNextID = 0;
+
+  // TODO: Need to fix this on WinCE build
+#ifndef _WIN32_WCE
   struct stat sFileInfo;
   string strFileName = UserLocation + "controllabels.xml";  //  check first location for file
   if(stat(strFileName.c_str(), &sFileInfo) == -1) {
@@ -37,6 +60,7 @@ CControlManager::CControlManager( CNodeCreationManager *pNCManager )
     LoadLabelsFromFile(strFileName, sFileInfo.st_size);
   
   ConnectNodes();
+#endif
 }
 
 int CControlManager::LoadLabelsFromFile(string strFileName, int iFileSize) {
@@ -273,7 +297,8 @@ CDasherNode *CControlManager::GetRoot(CDasherNode *pParent, int iLower, int iUpp
 }
 
 void CControlManager::PopulateChildren( CDasherNode *pNode ) {
-   CDasherNode *pNewNode;
+  
+  CDasherNode *pNewNode;
 
    CControlNode *pControlNode((static_cast<SControlData *>(pNode->m_pUserData))->pControlNode);
 
@@ -401,3 +426,6 @@ void CControlManager::XmlCDataHandler(void *pUserData, const XML_Char *szData, i
   return;
 }
 
+void CControlManager::SetControlOffset(CDasherNode *pNode, int iOffset) {
+  (static_cast<SControlData *>(pNode->m_pUserData))->iOffset = iOffset;
+}
