@@ -1,35 +1,31 @@
 #ifndef __dashercomponent_h__
 #define __dashercomponent_h__
 
+#include "SettingsStore.h"
 namespace Dasher {
-  class CDasherComponent;
   class CEvent;
   class CEventHandler;
-}
-
-
-class Dasher::CEvent;
-class Dasher::CEventHandler;
-#include "SettingsStore.h"
+  class CDasherComponent;
+};
 
 /// \ingroup Core
 /// @{
 class Dasher::CDasherComponent {
  public:
-  CDasherComponent(Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore);
-
+  CDasherComponent(Dasher::CEventHandler* pEventHandler, CSettingsStore* pSettingsStore);
   virtual ~CDasherComponent();
 
   void InsertEvent(Dasher::CEvent * pEvent);
-
   virtual void HandleEvent(Dasher::CEvent * pEvent) {};
 
   bool GetBoolParameter(int iParameter) const;
-  long GetLongParameter(int iParameter) const;
-  std::string GetStringParameter(int iParameter) const;
   void SetBoolParameter(int iParameter, bool bValue) const;
+
+  long GetLongParameter(int iParameter) const;
   void SetLongParameter(int iParameter, long lValue) const;
-  void SetStringParameter(int iParameter, std::string & sValue) const;
+
+  std::string GetStringParameter(int iParameter) const;
+  void        SetStringParameter(int iParameter, std::string & sValue) const;
 
   ParameterType   GetParameterType(int iParameter) const;
   std::string     GetParameterName(int iParameter) const;
@@ -40,4 +36,5 @@ class Dasher::CDasherComponent {
 };
 /// @}
 
+
 #endif
