@@ -38,13 +38,14 @@
 #include "BasicLog.h"
 #endif
 #include "WrapperFactory.h"
+//#include "DasherGameMode.h"
 
 // Input filters
 #include "ClickFilter.h" 
 #include "DefaultFilter.h"
 #include "DasherButtons.h"
-#include "DynamicFilter.h"
 #include "EyetrackerFilter.h"
+#include "OneButtonDynamicFilter.h"
 #include "OneDimensionalFilter.h"
 #include "StylusFilter.h"
 #include "TwoButtonDynamicFilter.h"
@@ -126,12 +127,11 @@ CDasherInterfaceBase::CDasherInterfaceBase() {
 }
 
 void CDasherInterfaceBase::Realize() {
-
   // TODO: What exactly needs to have happened by the time we call Realize()?
   CreateSettingsStore();
   SetupUI();
   SetupPaths();
-
+  
   std::vector<std::string> vAlphabetFiles;
   ScanAlphabetFiles(vAlphabetFiles);
   m_AlphIO = new CAlphIO(GetStringParameter(SP_SYSTEM_LOC), GetStringParameter(SP_USER_LOC), vAlphabetFiles);
@@ -141,7 +141,7 @@ void CDasherInterfaceBase::Realize() {
   m_ColourIO = new CColourIO(GetStringParameter(SP_SYSTEM_LOC), GetStringParameter(SP_USER_LOC), vColourFiles);
 
   ChangeColours();
-  ChangeAlphabet();
+  ChangeAlphabet(); // This creates the NodeCreationManager, the Alphabet
 
   // Create the user logging object if we are suppose to.  We wait
   // until now so we have the real value of the parameter and not
@@ -180,11 +180,18 @@ void CDasherInterfaceBase::Realize() {
 
   // TODO: Make things work when model is created latet
   ChangeState(TR_MODEL_INIT);
+
+  // Create the teacher singleton object. 
+  //  CDasherGameMode::CreateTeacher(m_pEventHandler, m_pSettingsStore, this);
 }
 
 CDasherInterfaceBase::~CDasherInterfaceBase() {
   DASHER_ASSERT(m_iCurrentState == ST_SHUTDOWN);
 
+  // It may seem odd that InterfaceBase does not "own" the teacher.
+  // This is because game mode is a different layer, in a sense.
+  //  CDasherGameMode::DestroyTeacher();
+
   delete m_pDasherModel;        // The order of some of these deletions matters
   delete m_Alphabet;
   delete m_pDasherView;
@@ -350,7 +357,8 @@ void CDasherInterfaceBase::InterfaceEventHandler(Dasher::CEvent *pEvent) {
 }
 
 void CDasherInterfaceBase::WriteTrainFileFull() {
-  WriteTrainFile(strTrainfileBuffer);
+  if(!GetBoolParameter(BP_GAME_MODE))
+    WriteTrainFile(strTrainfileBuffer);
   strTrainfileBuffer = "";
 }
 
@@ -370,12 +378,12 @@ void CDasherInterfaceBase::CreateModel(int iOffset) {
     m_pDasherModel = 0;
   }
   
-  if(m_deGameModeStrings.size() == 0) {
-    m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, m_pDasherView, iOffset);
-  }
-  else {
-    m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, m_pDasherView, iOffset, true, m_deGameModeStrings[0]);
-  }
+  m_pDasherModel = new CDasherModel(m_pEventHandler, m_pSettingsStore, m_pNCManager, this, m_pDasherView, iOffset);
+  
+  // Notify the teacher of the new model
+  //  if(CDasherGameMode* pTeacher = CDasherGameMode::GetTeacher())
+  //  pTeacher->SetDasherModel(m_pDasherModel);
+  
 }
 
 void CDasherInterfaceBase::CreateNCManager() {
@@ -415,16 +423,12 @@ void CDasherInterfaceBase::CreateNCManager() {
       delete m_pNCManager;
       m_pNCManager = 0;
     }
-      
-    if(m_deGameModeStrings.size() == 0) {
-      m_pNCManager = new CNodeCreationManager(this, m_pEventHandler, m_pSettingsStore, false, "", m_AlphIO);
-    }
-    else {
-      m_pNCManager = new CNodeCreationManager(this, m_pEventHandler, m_pSettingsStore, true, m_deGameModeStrings[0], m_AlphIO);
-    }
+  
+    m_pNCManager = new CNodeCreationManager(this, m_pEventHandler, m_pSettingsStore, m_AlphIO);
 
     m_Alphabet = m_pNCManager->GetAlphabet();
     
+    // TODO: Consider using GetStringParameter(SP_TRAIN_FILE) instead?
     string T = m_Alphabet->GetTrainingFile();
 
     int iTotalBytes = 0;
@@ -451,29 +455,6 @@ void CDasherInterfaceBase::CreateNCManager() {
     CreateModel(iOffset);
 }
 
-// void CDasherInterfaceBase::Start() {
-//   // TODO: Clarify the relationship between Start() and
-//   // InvalidateContext() - I believe that they essentially do the same
-//   // thing
-//   PauseAt(0, 0);
-//   if(m_pDasherModel != 0) {
-//     m_pDasherModel->Start();
-//   }
-//   if(m_pDasherView != 0) {
-// //     m_pDasherView->ResetSum();
-// //     m_pDasherView->ResetSumCounter();
-// //     m_pDasherView->ResetYAutoOffset();
-//   }
-
-// TODO: Reimplement this sometime
-
-//   int iMinWidth;
-  
-//   if(m_pInputFilter && m_pInputFilter->GetMinWidth(iMinWidth)) {
-//     m_pDasherModel->LimitRoot(iMinWidth);
-//   }
-// }
-
 void CDasherInterfaceBase::PauseAt(int MouseX, int MouseY) {
   SetBoolParameter(BP_DASHER_PAUSED, true);
 
@@ -489,6 +470,11 @@ void CDasherInterfaceBase::PauseAt(int MouseX, int MouseY) {
 #endif
 }
 
+void CDasherInterfaceBase::GameMessageIn(int message, void* messagedata) {
+  //  CDasherGameMode::GetTeacher()->Message(message, messagedata);
+}
+
+
 void CDasherInterfaceBase::Halt() {
   SetBoolParameter(BP_DASHER_PAUSED, true);
 
@@ -567,6 +553,13 @@ void CDasherInterfaceBase::NewFrame(unsigned long iTime, bool bForceRedraw) {
     }
   }
 
+  // Flags at this stage:
+  //
+  // - bChanged = the display was updated, so needs to be rendered to the display
+  // - m_bLastChanged = bChanged was true last time around
+  // - m_bRedrawScheduled = Display invalidated internally
+  // - bForceRedraw = Display invalidated externally
+
   // TODO: This is a bit hacky - we really need to sort out the redraw logic
   if((!bChanged && m_bLastChanged) || m_bRedrawScheduled || bForceRedraw) {
     m_pDasherView->Screen()->SetCaptureBackground(true);
@@ -582,7 +575,8 @@ void CDasherInterfaceBase::NewFrame(unsigned long iTime, bool bForceRedraw) {
   // know how often new frames are being drawn.
   if(m_pDasherModel != 0)
     m_pDasherModel->NewFrame(iTime);
-}
+
+ }
 
 void CDasherInterfaceBase::CheckRedraw() {
   if(m_bRedrawScheduled)
@@ -596,7 +590,6 @@ void CDasherInterfaceBase::CheckRedraw() {
 /// otherwise we're wasting effort.
 
 void CDasherInterfaceBase::Redraw(bool bRedrawNodes) {
-
   if(!m_pDasherView || !m_pDasherModel)
     return;
   
@@ -609,6 +602,9 @@ void CDasherInterfaceBase::Redraw(bool bRedrawNodes) {
   
   m_pDasherView->Screen()->SendMarker(1);
   
+  //  if(CDasherGameMode* pTeacher = CDasherGameMode::GetTeacher())
+  // pTeacher->DrawGameDecorations(m_pDasherView);
+    
   bool bDecorationsChanged(false);
 
   if(m_pInputFilter) {
@@ -625,7 +621,6 @@ void CDasherInterfaceBase::Redraw(bool bRedrawNodes) {
 }
 
 void CDasherInterfaceBase::ChangeAlphabet() {
-
   if(GetStringParameter(SP_ALPHABET_ID) == "") {
     SetStringParameter(SP_ALPHABET_ID, m_AlphIO->GetDefault());
     // This will result in ChangeAlphabet() being called again, so
@@ -666,6 +661,7 @@ void CDasherInterfaceBase::ChangeColours() {
 }
 
 void CDasherInterfaceBase::ChangeScreen(CDasherScreen *NewScreen) {
+  // What does ChangeScreen do? 
   m_DasherScreen = NewScreen;
   ChangeColours();
 
@@ -689,6 +685,11 @@ void CDasherInterfaceBase::ChangeView() {
  
     if (m_pInput)
       m_pDasherView->SetInput(m_pInput);
+    // Tell the Teacher which view we are using
+    //    if(CDasherGameMode* pTeacher = CDasherGameMode::GetTeacher())
+    // {/
+    //	pTeacher->SetDasherView(m_pDasherView);
+    // }
   }
 }
 
@@ -922,7 +923,7 @@ void CDasherInterfaceBase::KeyDown(int iTime, int iId, bool bPos, int iX, int iY
     return;
 
   if(m_pInputFilter && !GetBoolParameter(BP_TRAINING)) {
-    m_pInputFilter->KeyDown(iTime, iId, m_pDasherModel, m_pUserLog, bPos, iX, iY);
+    m_pInputFilter->KeyDown(iTime, iId, m_pDasherView, m_pDasherModel, m_pUserLog, bPos, iX, iY);
   }
 
   if(m_pInput && !GetBoolParameter(BP_TRAINING)) {
@@ -935,7 +936,7 @@ void CDasherInterfaceBase::KeyUp(int iTime, int iId, bool bPos, int iX, int iY)
     return;
 
   if(m_pInputFilter && !GetBoolParameter(BP_TRAINING)) {
-    m_pInputFilter->KeyUp(iTime, iId, m_pDasherModel, bPos, iX, iY);
+    m_pInputFilter->KeyUp(iTime, iId, m_pDasherView, m_pDasherModel, bPos, iX, iY);
   }
 
   if(m_pInput && !GetBoolParameter(BP_TRAINING)) {
@@ -986,8 +987,8 @@ void CDasherInterfaceBase::CreateFactories() {
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new COneDimensionalFilter(m_pEventHandler, m_pSettingsStore, this, m_pDasherModel)));
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CEyetrackerFilter(m_pEventHandler, m_pSettingsStore, this, m_pDasherModel)));
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CClickFilter(m_pEventHandler, m_pSettingsStore, this)));
-  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDynamicFilter(m_pEventHandler, m_pSettingsStore, this)));
-  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CTwoButtonDynamicFilter(m_pEventHandler, m_pSettingsStore, this, 14, 1, _("Two Button Dynamic Mode"))));
+  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new COneButtonDynamicFilter(m_pEventHandler, m_pSettingsStore, this)));
+  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CTwoButtonDynamicFilter(m_pEventHandler, m_pSettingsStore, this)));
   // TODO: specialist factory for button mode
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDasherButtons(m_pEventHandler, m_pSettingsStore, this, 5, 1, true,8, _("Menu Mode"))));
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDasherButtons(m_pEventHandler, m_pSettingsStore, this, 3, 0, false,10, _("Direct Mode"))));
