@@ -159,6 +159,8 @@ void CDasherModel::Make_root(CDasherNode *pNewRoot) {
   // TODO: Note that subnodes can be the root transiently during the
   // re-rooting process.
 
+  //  std::cout << "Make root" << std::endl;
+
   DASHER_ASSERT(pNewRoot != NULL);
   DASHER_ASSERT(pNewRoot->NodeIsParent(m_Root));
 
@@ -231,34 +233,18 @@ void CDasherModel::RebuildAroundNode(CDasherNode *pNode) {
   m_pLastOutput = m_Root;
 }
 
-// TODO: Need to make this do the right thing with subnodes
 void CDasherModel::Reparent_root(int lower, int upper) {
   DASHER_ASSERT(m_Root != NULL);
 
   // Change the root node to the parent of the existing node. We need
   // to recalculate the coordinates for the "new" root as the user may
   // have moved around within the current root
-
   CDasherNode *pNewRoot;
 
   if(oldroots.size() == 0) {
-    //    std::cout << "a" << std::endl;
-
-    // No nodes in the stack, so make a new one
-
-    // TODO: iGenerations is redundant, get rid of it
-    int iGenerations(0);
-    pNewRoot = m_Root->m_pNodeManager->RebuildParent(m_Root, iGenerations);
-
+    pNewRoot = m_Root->m_pNodeManager->RebuildParent(m_Root);
   }
   else {
-    //    std::cout << "b" << std::endl;
-
-    //    for(int i(0); i < oldroots.size(); ++i)
-    //      std::cout << oldroots[i]->GetFlag(NF_SUBNODE) << " ";
-    
-    //   std::cout << std::endl;
-
     pNewRoot = oldroots.back();
     oldroots.pop_back();
 
@@ -266,13 +252,6 @@ void CDasherModel::Reparent_root(int lower, int upper) {
       pNewRoot = oldroots.back();
       oldroots.pop_back();
     }
-
-    //    for(int i(0); i < oldroots.size(); ++i)
-    // std::cout << oldroots[i]->GetFlag(NF_SUBNODE) << " ";
-    
-    //std::cout << std::endl;
-    
-    // std::cout << "---" << std::endl;
   }
 
   // Return if there's no existing parent and no way of recreating one
@@ -297,10 +276,11 @@ void CDasherModel::Reparent_root(int lower, int upper) {
     myint iRootWidth = m_Rootmax - m_Rootmin;
     
     // Fail and undo root creation if the new root is bigger than allowed by normalisation
-    if(!(pNewRoot->GetFlag(NF_SUBNODE)) && (((myint((GetLongParameter(LP_NORMALIZATION) - upper)) / static_cast<double>(iWidth)) 
-	> (m_Rootmax_max - m_Rootmax)/static_cast<double>(iRootWidth)) || 
-       ((myint(lower) / static_cast<double>(iWidth)) 
-	> (m_Rootmin - m_Rootmin_min) / static_cast<double>(iRootWidth)))) {
+    if(!(pNewRoot->GetFlag(NF_SUBNODE)) && 
+       (((myint((GetLongParameter(LP_NORMALIZATION) - upper)) / static_cast<double>(iWidth)) >
+	 (m_Rootmax_max - m_Rootmax)/static_cast<double>(iRootWidth)) || 
+       ((myint(lower) / static_cast<double>(iWidth)) > 
+	(m_Rootmin - m_Rootmin_min) / static_cast<double>(iRootWidth)))) {
       pNewRoot->OrphanChild(m_Root);
       delete pNewRoot;
       return;
@@ -541,8 +521,6 @@ void CDasherModel::NewFrame(unsigned long Time) {
 }
 
 void CDasherModel::OldPush(myint iMousex, myint iMousey) {
-  std::cout << "Old Push" << std::endl;
-
   // push node under mouse
   CDasherNode *pUnderMouse = Get_node_under_mouse(iMousex, iMousey);
 
@@ -830,8 +808,7 @@ void CDasherModel::Push_Node(CDasherNode *pNode) {
 //       true;
 //     }
 
-  
- }
+}
 
 void CDasherModel::Recursive_Push_Node(CDasherNode *pNode, int iDepth) {
   // TODO: is this really useful? Doesn't Push_node itself recurse
@@ -870,6 +847,7 @@ bool CDasherModel::RenderToView(CDasherView *pView, bool bRedrawDisplay) {
   // the appropriate Nodes.
   bReturnValue = pView->Render(m_Root, m_Rootmin + m_iTargetOffset, m_Rootmax + m_iTargetOffset, vNodeList, vDeleteList, bRedrawDisplay, &vGameTargetY);
   
+
   /////////GAME MODE TEMP//////////////
 //   if(m_bGameMode)
 //     if(CDasherGameMode* pTeacher = CDasherGameMode::GetTeacher())
@@ -951,12 +929,10 @@ bool CDasherModel::CheckForNewRoot(CDasherView *pView) {
     // not true - pconlon
     ////GAME MODE TEMP - only change the root if it is on the game path/////////
 //       if(bFound && (!m_bGameMode || pNewRoot->GetFlag(NF_GAME)))
-// 	{
-// 	  m_Root->DeleteNephews(pNewRoot);
-// 	  //      std::cout << "m..." << std::endl;
-// 	  RecursiveMakeRoot(pNewRoot);
-// 	  //std::cout << "...m" << std::endl;
-// 	}
+    if(bFound) {
+      m_Root->DeleteNephews(pNewRoot);
+      RecursiveMakeRoot(pNewRoot);
+    }
   }
 
   CDasherNode *pNewNode = Get_node_under_crosshair();
@@ -1046,6 +1022,8 @@ void CDasherModel::SetOffset(int iLocation, CDasherView *pView) {
   if(iLocation == m_iOffset)
     return; // We're already there
   
+  //  std::cout << "Initialising at offset: " << iLocation << std::endl;
+
   // TODO: Special cases, ie this can be done without rebuilding the
   // model
 
