@@ -9,6 +9,7 @@
 #include "../../Common/Common.h"
 
 #include "LanguageModel.h"
+#include "../Alphabet/Alphabet.h"
 
 /////////////////////////////////////////////////////////////////////////////
 
@@ -33,4 +34,9 @@ CLanguageModel::CLanguageModel(Dasher::CEventHandler *pEventHandler, CSettingsSt
 void CLanguageModel::HandleEvent(Dasher::CEvent *pEvent) {
 }
 
+symbol CLanguageModel::GetResetSymbol() const
+{
+  return m_Alphabet.GetAlphabetPointer()->GetResetSymbol();
+};
+
 ///////////////////////////////////////////////////////////////////
