@@ -9,11 +9,14 @@
 #include "../../Common/Common.h"
 #include "WordLanguageModel.h"
 #include "PPMLanguageModel.h"
+#include "../Alphabet/Alphabet.h"
+
 
 #include <cmath>
-#include <stack>
-#include <iostream>
+#include <cstdlib>
 #include <fstream>
+#include <iostream>
+#include <stack>
 
 using namespace Dasher;
 using namespace std;
@@ -27,7 +30,7 @@ typedef unsigned long ulong;
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -229,7 +232,7 @@ int CWordLanguageModel::lookup_word_const(const std::string &w) const {
 /////////////////////////////////////////////////////////////////////
 // get the probability distribution at the context
 
-void CWordLanguageModel::GetProbs(Context context, std::vector<unsigned int> &probs, int norm) const {
+void CWordLanguageModel::GetProbs(Context context, std::vector<unsigned int> &probs, int norm, int iUniform) const {
   // Got rid of const below
 
   CWordLanguageModel::CWordContext * wordcontext = (CWordContext *) (context);
@@ -302,7 +305,7 @@ void CWordLanguageModel::GetProbs(Context context, std::vector<unsigned int> &pr
 
   int iSpellingNorm(wordcontext->m_iSpellingNorm);
 
-  wordcontext->m_pSpellingModel->GetProbs(wordcontext->oSpellingContext, wordcontext->oSpellingProbs, iSpellingNorm);
+  wordcontext->m_pSpellingModel->GetProbs(wordcontext->oSpellingContext, wordcontext->oSpellingProbs, iSpellingNorm, 0);
 
   double dNorm(0.0);
 
