@@ -7,7 +7,7 @@
 #include "ControlManagerFactory.h"
 #include "ConversionManagerFactory.h"
 #include "DasherComponent.h"
-//#include "DasherNode.h"
+
 #include "LanguageModelling/LanguageModel.h"
 
 #include <string>
@@ -17,24 +17,29 @@ namespace Dasher {
   class CDasherNode;
   class CDasherInterfaceBase;
 };
-
+/// \ingroup Model
+/// @{
 class CNodeCreationManager : public Dasher::CDasherComponent {
  public:
-  CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterface, Dasher::CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, bool bGameMode, std::string strGameModeText, Dasher::CAlphIO *pAlphIO);
+  CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterface,
+		       Dasher::CEventHandler * pEventHandler,
+		       CSettingsStore * pSettingsStore,
+		       Dasher::CAlphIO *pAlphIO);
   ~CNodeCreationManager();
   
   ///
   /// Get a root node of a given type
   ///
 
-  CDasherNode *GetRoot(int iType, CDasherNode *pParent, int iLower, int iUpper, void *pUserData);
+  CDasherNode *GetRoot(int iType, Dasher::CDasherNode *pParent, int iLower, int iUpper, void *pUserData);
 
   ///
   /// Resgister a control node 
   ///
 
   void RegisterNode( int iID, const std::string &strLabel, int iColour ) {
-    m_pControlManagerFactory->RegisterNode(iID, strLabel, iColour);
+    if(m_pControlManagerFactory)
+      m_pControlManagerFactory->RegisterNode(iID, strLabel, iColour);
   }
 
   ///
@@ -42,7 +47,8 @@ class CNodeCreationManager : public Dasher::CDasherComponent {
   ///
   
   void ConnectNode(int iChild, int iParent, int iAfter) {
-    m_pControlManagerFactory->ConnectNode(iChild, iParent, iAfter);
+    if(m_pControlManagerFactory)
+      m_pControlManagerFactory->ConnectNode(iChild, iParent, iAfter);
   }
 
   ///
@@ -50,7 +56,8 @@ class CNodeCreationManager : public Dasher::CDasherComponent {
   ///
 
   void DisconnectNode(int iChild, int iParent) {
-    m_pControlManagerFactory->DisconnectNode(iChild, iParent);
+    if(m_pControlManagerFactory)
+      m_pControlManagerFactory->DisconnectNode(iChild, iParent);
   }
 
   ///
@@ -69,8 +76,8 @@ class CNodeCreationManager : public Dasher::CDasherComponent {
   void LearnText(CLanguageModel::Context context, std::string *TheText, bool IsMore);
   void EnterText(CLanguageModel::Context context, std::string TheText) const;
 
-  inline int GetColour(symbol s) const { 
-    return m_pAlphabet->GetColour(s); 
+  inline int GetColour(symbol s, int iPhase) const { 
+    return m_pAlphabet->GetColour(s, iPhase); 
   };
 
   ///
@@ -132,5 +139,6 @@ class CNodeCreationManager : public Dasher::CDasherComponent {
   CControlManagerFactory *m_pControlManagerFactory;
   CConversionManagerFactory *m_pConversionManagerFactory;
 };
+/// @}
 
 #endif
