@@ -51,6 +51,11 @@ void CDasherControl::CreateLocalFactories() {
   RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDasherJoystickInputDiscrete(m_pEventHandler, m_pSettingsStore, this)));
 #endif
   
+#ifdef TILT
+  RegisterFactory(new CWrapperFactory(m_pEventHandler, m_pSettingsStore, new CDasherTiltInput(m_pEventHandler, m_pSettingsStore, this)));
+#endif
+  
+  
   // Create locally cached copies of the mouse input objects, as we
   // need to pass coordinates to them from the timer callback
   
@@ -223,6 +228,10 @@ void CDasherControl::SetFocus() {
   gtk_widget_grab_focus(m_pCanvas);
 }
 
+void CDasherControl::GameMessageOut(void* gameHelper, int message, const void* messagedata) {
+  gtk_dasher_control_game_messageout(m_pDasherControl, gameHelper, message, messagedata);
+}
+
 GArray *CDasherControl::GetAllowedValues(int iParameter) {
   // Glib version of the STL based core function
 
@@ -438,6 +447,7 @@ int CDasherControl::TimerEvent() {
       int iMouseY = 0;  
       gdk_window_get_pointer(NULL, &iMouseX, &iMouseY, NULL);
 
+      // TODO: This sort of thing shouldn't be in specialised methods, move into base class somewhere
       pUserLog->AddMouseLocationNormalized(iMouseX, iMouseY, true, GetNats());
   }
 
