@@ -884,7 +884,15 @@ extern "C" void uniform_changed(GtkHScale *hscale) {
   //  DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(pSelf);
   DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(g_pPreferencesDialogue); // TODO: Fix NULL
 
-  dasher_app_settings_set_long(pPrivate->pAppSettings, LP_UNIFORM, int (GTK_RANGE(hscale)->adjustment->value * 10));
+  
+  int iValue = (int)(GTK_RANGE(hscale)->adjustment->value * 10);
+
+  if(iValue < 50) {
+    iValue = 50;
+    gtk_range_set_value(GTK_RANGE(glade_xml_get_widget(pPrivate->pGladeXML, "uniformhscale")), 5.0);
+  }
+  
+  dasher_app_settings_set_long(pPrivate->pAppSettings, LP_UNIFORM, iValue);
 }
 
 extern "C" gboolean show_helper_window(GtkWidget *pWidget, gpointer *pUserData) {
@@ -978,6 +986,7 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
 
   pRenderer = gtk_cell_renderer_toggle_new();
   g_signal_connect(pRenderer, "toggled", (GCallback)on_action_toggle, pColumnIndex);
+  /* TRANSLATORS: Show a button for the selected action in the Dasher window. */
   pColumn = gtk_tree_view_column_new_with_attributes(_("Show Button"), pRenderer, "active", ACTIONS_SHOW_COLUMN, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
@@ -988,6 +997,7 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
 
   pRenderer = gtk_cell_renderer_toggle_new();
   g_signal_connect(pRenderer, "toggled", (GCallback)on_action_toggle, pColumnIndex + 2);
+  /* TRANSLATORS: Automatically perform the selected action when Dasher is stopped. */
   pColumn = gtk_tree_view_column_new_with_attributes(_("Auto On Stop"), pRenderer, "active", ACTIONS_AUTO_COLUMN, NULL);
   gtk_tree_view_append_column(GTK_TREE_VIEW(pPrivate->pActionTreeView), pColumn);
 
