@@ -20,6 +20,9 @@
 class CAdvancedPage:public CPrefsPageBase {
 public:
   CAdvancedPage(HWND Parent, CDasherInterfaceBase * DI, CAppSettings *pAppSettings);
+  
+  LRESULT WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam);
+
 protected:
 private:
   HWND CustomBox;
@@ -35,7 +38,6 @@ private:
   void InitCustomBox();
   bool UpdateInfo();
   bool Apply();
-  bool Validate();
 
  TCHAR m_tcBuffer[1000];
 
