@@ -10,17 +10,16 @@
 #define __AlphabetBox_h__
 
 #include "../resource.h"
-#include "../../DasherCore/Alphabet/AlphIO.h"
-#include "../DasherInterface.h"
-#include "WinWrap.h"
+//#include "../../DasherCore/Alphabet/AlphIO.h"
+#include "PrefsPageBase.h"
 
-class CAlphabetBox:public CWinWrap {
+class CAlphabetBox : public CPrefsPageBase {
 public:
-  CAlphabetBox(HWND Parent, CDasherInterface *DI);
+  CAlphabetBox(HWND Parent, CDasherInterfaceBase *DI, CAppSettings *pAppSettings);
 protected:
   LRESULT WndProc(HWND Window, UINT message, WPARAM wParam, LPARAM lParam);
 private:
-  CDasherInterface * m_pDasherInterface;
+  CDasherInterfaceBase * m_pDasherInterface;
   HWND m_hPropertySheet;
 
   HWND CustomBox;
@@ -30,7 +29,7 @@ private:
   Dasher::CAlphIO::AlphInfo CurrentInfo;
 
   std::vector < std::string > ColourList;
-  std::string m_CurrentColours;
+  
   Dasher::CColourIO::ColourInfo CurrentColourInfo;
 
   // Some status flags:
@@ -40,17 +39,22 @@ private:
   unsigned int CurrentGroup;
   unsigned int CurrentChar;
 
+ HWND slider;
+  HWND uniformbox;
+
+  TCHAR m_tcBuffer[1000];
+
+
   void PopulateList();
-  void InitCustomBox();
+  /*void InitCustomBox();
   std::string GetControlText(HWND Dialog, int ControlID);
   void NewGroup(std::string NewGroup);
   void ShowGroups();
   void ShowGroupChars();
   void CustomCharacter(std::string Display, std::string Text, int Colour);
-  bool UpdateInfo();
+  bool UpdateInfo();*/
   bool Apply();
-  bool Validate();
-
+ 
 };
 
 #endif /* #ifndef __AlphabetBox_h__ */
